"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var jstack_parse_1 = require("../jstack-parse");
test('parse', function () {
    var _a;
    var jstack = fs_1.default.readFileSync(path_1.default.resolve(__dirname, 'jstack-output-01.txt'), 'utf-8');
    var result = jstack_parse_1.parseJStack(jstack);
    expect((_a = result.dateTime) === null || _a === void 0 ? void 0 : _a.getTime()).toBe(new Date(2020, 1 - 1, 25, 13, 50, 13).getTime());
    expect(result.jdk).toBe('OpenJDK 64-Bit Server VM (11.0.5+10 mixed mode)');
    expect(result.jniGlobalRefs).toBe(19);
    expect(result.jniWeakRefs).toBe(19);
    expect(result.threads.length).toBe(30);
    var thread = result.threads[0];
    expect(thread.name).toBe('Reference Handler');
    expect(thread.daemon).toBe(true);
    expect(thread.javaThreadId).toBe(2);
    expect(thread.osPriority).toBe(0);
    expect(thread.priority).toBe(10);
    expect(thread.cpuTimeMillis).toBe(1.97);
    expect(thread.elapsedTimeMillis).toBe(564397290);
    expect(thread.tid).toBe('0x00007f09302b5800');
    expect(thread.nid).toBe(62);
    expect(thread.stackMemoryRegion).toBe('0x00007f090058c000');
    expect(thread.info).toBe('waiting on condition');
    expect(thread.state).toBe(jstack_parse_1.JStackThreadState.RUNNABLE);
});
test('parse alternate JNI references', function () {
    var result = jstack_parse_1.parseJStack('JNI global references: 123');
    expect(result.jniGlobalRefs).toBe(123);
});
test('Operation not permitted', function () {
    try {
        jstack_parse_1.parseJStack('', '123: Operation not permitted');
        fail('Should not get here');
    }
    catch (err) {
        expect(err.message).toBe('Operation not permitted');
    }
});
test('No such process', function () {
    try {
        jstack_parse_1.parseJStack('', '123: No such process');
        fail('Should not get here');
    }
    catch (err) {
        expect(err.message).toBe('No such process');
    }
});
test('JAVA_TOOL_OPTIONS', function () {
    var stderr = 'Picked up JAVA_TOOL_OPTIONS: -Dfile.encoding=UTF-8\n' +
        'Picked up _JAVA_OPTIONS: -Djava.net.preferIPv4Stack=true\n';
    var jstack = fs_1.default.readFileSync(path_1.default.resolve(__dirname, 'jstack-output-01.txt'), 'utf-8');
    jstack_parse_1.parseJStack(jstack, stderr);
});
//# sourceMappingURL=jstack.test.js.map