"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var clean_stderr_1 = require("./clean-stderr");
function parseJmapHisto(output, stderr) {
    if (stderr) {
        stderr = clean_stderr_1.cleanStderr(stderr);
        if (stderr.length > 0) {
            throw new Error("Unhandled error: " + stderr);
        }
    }
    var lines = output.split('\n');
    var results = {
        objects: [],
    };
    for (var i = 0; i < lines.length;) {
        var line = lines[i];
        i++;
        var objLineMatch = line.match(/[\s]*([0-9]+):[\s]+([0-9]+)[\s]+([0-9]+)[\s]+(.*)/);
        if (objLineMatch) {
            results.objects.push({
                instances: parseInt(objLineMatch[2], 10),
                bytes: parseInt(objLineMatch[3], 10),
                className: objLineMatch[4],
            });
            continue;
        }
        if (line.startsWith('Total')) {
            continue;
        }
        if (line.match(/num.*#instances.*#bytes.*class name \(module\)/)) {
            continue;
        }
        if (line.match(/num.*#instances.*#bytes.*class name/)) {
            continue;
        }
        if (line.startsWith('-----------------')) {
            continue;
        }
        if (line.trim().length === 0) {
            continue;
        }
        throw new Error("Unhandled line: " + line + " (line " + i + ")");
    }
    return results;
}
exports.parseJmapHisto = parseJmapHisto;
//# sourceMappingURL=jmap-histo-parse.js.map