"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var clean_stderr_1 = require("./clean-stderr");
function parseJps(output, stderr) {
    if (stderr) {
        stderr = clean_stderr_1.cleanStderr(stderr);
        if (stderr.length > 0) {
            throw new Error("Unhandled error: " + stderr);
        }
    }
    var lines = output.split('\n');
    var results = {
        processes: [],
    };
    for (var i = 0; i < lines.length;) {
        var line = lines[i];
        i++;
        var lineMatch = line.match(/^([0-9]+) (.+)$/);
        if (lineMatch) {
            var pid = parseInt(lineMatch[1], 10);
            var details = lineMatch[2];
            var detailsMatch = details.match(/^(.+?) (.+)$/);
            if (detailsMatch) {
                var className = detailsMatch[1];
                var name_1 = getNameFromClassName(className);
                var args = detailsMatch[2].split(' ');
                results.processes.push({ pid: pid, name: name_1, className: className, args: args });
            }
            else {
                var name_2 = details;
                results.processes.push({ pid: pid, name: name_2 });
            }
            continue;
        }
        var pidOnlyMatch = line.match(/^([0-9]+)$/);
        if (pidOnlyMatch) {
            var pid = parseInt(pidOnlyMatch[1], 10);
            results.processes.push({ pid: pid });
            continue;
        }
        if (line.trim().length === 0) {
            continue;
        }
        throw new Error("Unhandled line: " + line + " (line " + i + ")");
    }
    return results;
}
exports.parseJps = parseJps;
function getNameFromClassName(className) {
    var lastPeriod = className.lastIndexOf('.');
    if (lastPeriod >= 0) {
        return className.substring(lastPeriod + 1);
    }
    return className;
}
//# sourceMappingURL=jps-parse.js.map